# Python modules

import os, sys

# include files for QT

from qt import *

# application specific includes

from view     import *
from pinyin   import uniPinyin
from charmap  import uniCharmap

from kuralib.config import Config

ID_STATUS_MSG               = 1001

def Icon(pixmap):
  return QIconSet(QPixmap(os.path.join(os.environ["KURADIR"], "pixmaps", pixmap)))

def i18n(text):
  return text

class QCharMap(QMainWindow):

  def __init__(self, *args):
    QMainWindow.__init__(self, None, 'Unicode Editor',
			 Qt.WDestructiveClose)  

    self.initMenuBar()
    self.initToolBar()
    self.initStatusBar()
    self.initView()
    self.fileName=""
    self.font=Config.font
    
  def initMenuBar(self):

    # MENUBAR

    # menuBar entry self.file_menu

    self.file_menu = QPopupMenu()
    self.file_menu.insertItem(QIconSet(Icon("fileopen.xpm")), '&Open utf8 text', self.slotFileOpen,
			 Qt.CTRL+Qt.Key_O)
    self.file_menu.insertItem(QIconSet(Icon("filefloppy.xpm")), '&Save utf8 text', self.slotFileSave,
			 Qt.CTRL+Qt.Key_S)

    self.file_menu.insertSeparator()
    self.file_menu.insertItem(QIconSet(Icon("exit.xpm")), '&Quit', self.slotFileQuit,
			 Qt.CTRL+Qt.Key_Q)

    self.edit_menu = QPopupMenu()
    self.edit_menu.insertItem(QIconSet(Icon("editcut.xpm")), i18n("C&ut"),self.slotEditCut, Qt.CTRL+Qt.Key_Delete)
    self.edit_menu.insertItem(QIconSet(Icon("editcopy.xpm")), i18n("&Copy"),self.slotEditCopy, Qt.CTRL+Qt.Key_Insert)
    self.edit_menu.insertItem(QIconSet(Icon("delete.xpm")), i18n("&Delete"),self.slotEditDelete)
    self.edit_menu.insertSeparator()
    self.edit_menu.insertItem(QIconSet(Icon("text.xpm")), i18n("&Font"), self.slotEditFont)
    
    self.options_menu=QPopupMenu()
    self.options_menu.insertItem(i18n("&Windows"), self.slotOptionsWindows)
    self.options_menu.insertItem(i18n("&Motif"), self.slotOptionsMotif)    
    self.options_menu.insertItem(i18n("&Platinum"), self.slotOptionsPlatinum)    

    # menuBar entry help_menu
    self.help_menu = QPopupMenu()
    self.help_menu.insertItem("About...", self.slotHelpAbout, Qt.Key_F1)
    self.help_menu.insertItem('About &Qt', self.slotQtAbout)

    # MENUBAR CONFIGURATION
    
    self.menuBar().insertItem(i18n("&File"), self.file_menu)
    self.menuBar().insertItem(i18n("&Edit"), self.edit_menu)
    self.menuBar().insertItem("Options", self.options_menu)
    self.menuBar().insertSeparator()
    self.menuBar().insertItem(i18n("&Help"), self.help_menu)

  def initToolBar(self):

    # TOOLBAR
    self.toolbar=QToolBar(self, 'main toolbar')
    self.buttons=[]
    self.buttons.append(QToolButton( Icon("fileopen.xpm")
                                   , "Open"
                                   , "Open an utf8 text"
                                   , self.slotFileOpen
                                   , self.toolbar
                                   )
                       )
    self.buttons.append(QToolButton( Icon("filefloppy.xpm")
                                   , "Save"
                                   , "Save an utf8 text."
                                   , self.slotFileSave
                                   , self.toolbar
                                   )
                       )                       
    self.toolbar.addSeparator()
    self.buttons.append(QToolButton( Icon("editcut.xpm")
                                   , "Cut"
                                   , "Put the text on the clipboard and clear the edit area."
                                   , self.slotEditCopy
                                   , self.toolbar
                                   )
                       )
    self.buttons.append(QToolButton( Icon("editcopy.xpm")
                                   , "Copy"
                                   , "Put the text on the clipboard."
                                   , self.slotEditCopy
                                   , self.toolbar
                                   )
                       )                       
    self.buttons.append(QToolButton( Icon("delete.xpm")
                                   , "Delete"
                                   , "Clear the text."
                                   , self.slotEditDelete
                                   , self.toolbar
                                   )
                       )

    self.toolbar.addSeparator()
    self.buttons.append(QToolButton( Icon("text.xpm")
                                   , "Font"
                                   , "Change the font"
                                   , self.slotEditFont
                                   , self.toolbar
                                   )
                       )

    self.toolbar.addSeparator()
    self.buttons.append(QToolButton( Icon("exit.xpm")
                                   , "Exit"
                                   , "Exit qcharbrowser"
                                   , self.slotFileQuit
                                   , self.toolbar
                                   )
                       )

  def initStatusBar(self):
    self.statusBar().message(i18n("Ready."), ID_STATUS_MSG )

  def initView(self):
    self.view = QCharView(self, Config.font)
    self.connect(self, PYSIGNAL("sigFontChanged"), self.view.setFont)
    self.setCentralWidget(self.view)
    self.setCaption("Unicode Editor")
    self.view.setFocus()

  def slotFileOpen(self):
    fileName = QFileDialog.getOpenFileName(QString.null, QString.null, self)
    if not fileName.isEmpty():
      text=open(str(fileName)).read()
      self.view.editField.setText(unicode(text))
    self.fileName=fileName

  def closeEvent(self, e):
    #self.view.editField.setText("")
    #QApplication.clipboard().clear()
    e.accept()

  def slotFileQuit(self):
    self.close()
    
  def slotFileSave(self):
    fileName = QFileDialog.getSaveFileName(self.fileName)
    if not fileName.isEmpty():
      f=open(str(fileName), "w+")
      f.write(unicode(self.view.editField.text()))

  def slotEditFont(self):
    font, OK=QFontDialog.getFont(self.view.font, self)
    if OK: self.emit(PYSIGNAL("sigFontChanged"),(font,))
    
  def slotEditCut(self):
    self.view.copy()
    self.view.clear()
    
  def slotEditCopy(self):
    self.view.copy()
    
  def slotEditDelete(self):  
    self.view.clear()
    
  def slotEditKeyboard(self):
    pass
    
  def slotOptionsWindows(self): 
    self.style=QWindowsStyle()
    qApp.setStyle(self.style)
  
  def slotOptionsMotif(self): 
    self.style=QMotifStyle(TRUE)
    qApp.setStyle(self.style)
  
  def slotOptionsPlatinum(self):     
    self.style=QPlatinumStyle()
    qApp.setStyle(self.style)

  def slotHelpAbout(self):
    QMessageBox.about(self, 'Unicode Character Map',"A Unicode editor for Kura.")
  
  def slotQtAbout(self):
    QMessageBox.aboutQt(self, 'Unicode Character Map')


__copyright__="""
/***************************************************************************
    copyright            : (C) 2000 by Boudewijn Rempt 
                           see copyright notice for license
    email                : boud@rempt.xs4all.nl
    Revision             : $Revision: 1.7 $
    Last edited          : $Date: 2001/01/30 20:04:39 $
    
    CVS Log:         
    $Log: mainwin.py,v $
    Revision 1.7  2001/01/30 20:04:39  boud
    Removed print statements.

    Revision 1.6  2001/01/30 19:35:32  boud
    Fixed segfault when the charmap canvas was recreated a few times
    by _not_ giving the canvas a parent QObject.

    Revision 1.5  2001/01/30 18:35:19  boud
    Help strings were very wrong.

    Revision 1.4  2001/01/30 18:06:53  boud
    Made a package.

    Revision 1.3  2001/01/08 20:54:56  boud
    Cleanup for version 1.0

 ***************************************************************************/
"""
