create table lng_project
( projectnr   serial not null UNIQUE
,    primary key (projectnr)
, description varchar(255)
, summary     text
, url         varchar(255)
, grants      text
, documentroot int8
);

create table lng_user
( usernr     serial not null UNIQUE
,    primary key (usernr)
, name       varchar(255) not null
, title      varchar(255)
, affiliationcode varchar(5)
, email      varchar(255)
, snailmail  varchar(255)
, fax        varchar(255)
, telephone  varchar(255)
, url        varchar(255)
);

create table lng_document
( documentnr serial not null UNIQUE
,    primary key (documentnr)
, title      varchar(255) not null
, description text
, creation_date date
, url         varchar(255) not null
, usernr     int8
);

create index i_doc_1 on lng_document (title);
create index i_doc_2 on lng_document (url);

create table lng_doc_doc
( docdocnr    serial not null UNIQUE
,     primary key (docdocnr)
, documentnr_1 int8 not null
, documentnr_2 int8 not null
, linkcode varchar(5) not null
, description varchar(50)
);

create table lng_doc_refs
( documentnr int8 not null
, referencenr int8 not null
,     primary key (documentnr, referencenr)
);

create table lng_linkcode
( linkcode   varchar(5) not null
,     primary key (linkcode)
, description varchar(255) not null
);

create table lng_language
( languagenr serial not null UNIQUE
,    primary key (languagenr)
, language   varchar(255) not null
, parent_languagenr int8
, description text
, documentroot int8
);

create table lng_reference
( referencenr serial not null UNIQUE
,    primary key (referencenr)
, author      varchar(255) not null
, year        varchar(4) not null
, title       varchar(255) not null
, place       varchar(255) not null
, catalogue_card text
, note           text
, main_categorycode varchar(10) not null
, sub_categorycode  varchar(10) not null
);

create index i_refs_1 on lng_reference (author);
create index i_refs_2 on lng_reference (year);
create index i_refs_3 on lng_reference (title);
create index i_refs_4 on lng_reference (place);
create index i_refs_5 on lng_reference (main_categorycode);
create index i_refs_6 on lng_reference (sub_categorycode);

create table lng_proj_user
( prusnr    serial not null UNIQUE
, projectnr int8 not null
, usernr    int8 not null
,    primary key (prusnr)
);

create table  lng_proj_lngg
( prlnnr      serial not null UNIQUE
, projectnr   int8 not null
, languagenr  int8 not null
,    primary key (prlnnr)
);

create table lng_recording
( recordingnr serial not null UNIQUE
,    primary key (recordingnr)
, description text
, url         varchar(255) not null
, source      varchar(255)
, tapenr      varchar(255)
, tape_location varchar(255)
, informant   varchar(255)
, duration    int8
, title       varchar(255) not null
, usernr      int8
, recording_date date 
, languagenr  int8 not null
, projectnr  int8 not null
);

create table lng_scan
( scannr     serial not null UNIQUE
,    primary key (scannr)
, description text
, url        varchar(255)
, manuscript_location varchar(255)
, title      varchar(255)  not null
, page       varchar(255)
, usernr     int8
, scan_date  date
, size       varchar(255)
, languagenr  int8 not null
, projectnr int8  not null
);

create table lng_text
( textnr     serial not null UNIQUE
,    primary key (textnr)
, recordingnr int8
, scannr     int8
, description text
, url        varchar(255)
, title      varchar(255)   not null
, usernr     int8
, transcription_date date
, raw_text   text           not null
, languagenr int8  not null
);

create table lng_proj_text
( prtxnr     serial not null UNIQUE
, projectnr  int8 not null
, textnr     int8 not null
,    primary key (prtxnr)
);

create table lng_stream
( streamnr   serial not null UNIQUE
,    primary key (streamnr)
, textnr     int8 not null
, seqnr      int  not null  
, text       text           not null
, languagenr int8
, usernr     int8
, datestamp  timestamp
);

create unique index u_strm on lng_stream (textnr, seqnr);

create table lng_element
( elementnr  serial not null UNIQUE
,    primary key (elementnr)
, streamnr   int8 not null
, seqnr      int  not null
, parent_elementnr int8 not null default 0
, text       varchar(255) not null
, elementypecode varchar(
, lexnr      int8
, languagenr int8
, usernr     int8
, datestamp  timestamp
);

create unique index u_elmt on lng_element (streamnr, seqnr);
create index i_elmt_1 on lng_element (streamnr);
create index i_elmt_2 on lng_element (parent_elementnr);
create index i_elmt_3 on lng_element (text);
create index i_elmt_4 on lng_element (lexnr);
create index i_elmt_4 on lng_element (languagenr);

create table lng_lex
( lexnr      serial not null UNIQUE
,    primary key (lexnr)
, form       varchar(50) not null
, phonetic_form varchar(100)
, glosse      varchar(255)
, description text
, languagenr  int8 not null
, usernr      int8
, datestamp   timestamp
);

create index i_lex on lng_lex (form);

create table lng_lex_lex
( lxlxnr      serial not null UNIQUE
,    primary  key (lxlxnr)
, lexnr_1     int8 not null
, lexnr_2     int8 not null
, lxlxrelcode varchar(255)
, note        text
, usernr      int8
, datestamp   timestamp
);

create unique index u_lxlx on lng_lex_lex (lexnr_1, lexnr_2);

create table lng_lxlxrelcode
( lxlxrelcode varchar(10) not null
,   primary key(lxlxrelcode)
, description varchar(255)
);

create table lng_text_tag
( text_tagnr int8  not null 
,   primary key (text_tagnr)
, textnr     int8 not null
, tag        varchar(50)  not null
, value      varchar(200) not null
, description varchar(200)
, note       text
, usernr     int8
, datestamp  timestamp
);

create index i_txtg_1 on lng_text_tag (textnr);
create index i_txtg_2 on lng_text_tag (tag);

create table lng_stream_tag
( stream_tagnr int8 not null
,   primary key (stream_tagnr)
, streamnr   int8 not null
, tag        varchar(50)  not null
, value      varchar(200)
, description varchar(200)
, note       text
, usernr     int8
, datestamp  timestamp
);

create index i_sttg_1 on lng_stream_tag (streamnr);
create index i_sttg_2 on lng_stream_tag (tag);

create table lng_element_tag
( element_tagnr int8 not null
,   primary key (element_tagnr)
, elementnr  int8 not null
, tag        varchar(50)  not null
, value      varchar(200)
, description varchar(200)
, note       text
, usernr     int8
, datestamp  timestamp
);

create index i_elmt_1 on lng_element_tag (elementnr);
create index i_elmt_2 on lng_element_tag (tag);

create table lng_lex_tag
( lex_tagnr  int8 not null
,   primary key (lex_tagnr)
, lexnr      int8 not null
, tag        varchar(50)  not null
, value      varchar(200)
, description varchar(200)
, note       text
, usernr     int8
, datestamp  timestamp
);

create index i_lxtg_1 on lng_lex_tag (lexnr);
create index i_lxtg_2 on lng_lex_tag (tag);

create table lng_tag
( tag         varchar(50) not null
,    primary key (tag)
, name        varchar(255) not null unique
,    unique (name)
, description text
, tagtypecode varchar(5) not null
, text        numeric(1,0) not null default 1
, stream      numeric(1,0) not null default 1
, element     numeric(1,0) not null default 1
, lexeme      numeric(1,0) not null default 1
, stylecode   varchar(50)
);

create table lng_stylecode
( stylecode   varchar(50) not null
,    primary key (stylecode)
, description varchar(200) not null
, font        varchar(50)  not null default "misc-fixed"
, weight      int8         not null default 50
, italic      numeric(1,0) not null default 0
, size        int8         not null default 12
, charset     int8         not null default 22
, showifnull  numeric(1,0) not null default 1
, wordwrap    numeric(1,0) not null default 1
);


create table lng_tagtypecode
( tagtypecode varchar(5) not null
,    primary key (tagtypecode)
, description varchar(255) not null
, isdomain    numeric(1,0) not null default 0
, isvalue     numeric(1,0) not null default 1
, isnote      numeric(1,0) not null default 0
, isreference numeric(1,0) not null default 0
);

create table lng_tagdomain
( domainnr serial not null UNIQUE
,    primary key (domainnr) 
, abbreviation varchar(10) not null
, tag          varchar(50) not null
,    unique (abbreviation, tag)
, description  varchar(50) 
);

create table lng_affiliationcode
( affiliationcode  varchar(10) not null
,    primary key (affiliationcode)
, description      varchar(255) not null
, institution      varchar(255)
, url              varchar(255)
);

create table lng_elementtypecode
( elementtypecode         varchar(10) not null
,    primary key (elementtypecode)
, description             varchar(250) not null
, parent_elementtypecode  varchar(10)
, stylecode               varchar(50)
, splitmarker             varchar(1) not null default ' '
, joinmarker              varchar(1) not null default ' '
);


create table lng_categorycode
( categorycode varchar(10) not null
,    primary key (categorycode)
, description varchar(255) not null
);
