from qt             import *

from dbobj.dbobj    import dbError

from frmlexchooser  import frmLexChooser
from kuracomboproxy import comboProxy

from resource       import *
from kuralib.config import Config

class listViewProxy(QObject):

  def __init__(self, listView, tableName, headers):
    QObject.__init__(self)
    self.listView=listView
    self.tableName=tableName
    self.rows={}
    self.headers=headers
  
    self.connect(self.listView, SIGNAL("doubleClicked(QListViewItem *)")
                     , self.slotItemSelected)
                     
  def slotItemSelected(self):
    self.emit(PYSIGNAL("sigItemSelected"), ( self.rows[self.listView.currentItem()]
                                           , self.listView.currentItem()
                                           )
             )
    
  def slotAddItem(self, rec, otherLvi=None):
    """
      Add a record to the listview and the cache.
    """
    lvi=QListViewItem(self.listView)
    col=0
    for fieldname in self.headers:
      lvi.setText(col, rec.getFieldValue(fieldname))
      col=col+1   
    self.rows[lvi]=rec
    
    if otherLvi!=None:
      self.emit(PYSIGNAL("sigItemAdded"), (rec, otherLvi))

  def slotDeleteItem(self, rec, lvi):
    del self.rows[lvi]
    self.listView.takeItem(lvi)

  def currentRecord(self):
    return self.rows[self.listView.currentItem()]

  def refresh(self, searchRec):
    self.listView.clear()
    self.rows={}
    rows=Config.app.getObjects(self.tableName, fields=searchRec.getFields())
    for row in rows:
      self.slotAddItem(row)

  def refreshRows(self, rows):
    self.listView.clear()
    self.rows={}
    for row in rows:
      self.slotAddItem(row)

class dlgLexChooser(frmLexChooser):

  def __init__(self, parent, parentRecord):
  
    frmLexChooser.__init__(self, parent=parent
                               , name="dlgLexChooser"
                               , modal=TRUE)
    
    self.txtForm.setFont(Config.font)
    self.txtPhoneticForm.setFont(Config.font)
    self.txtGlosse.setFont(Config.font)
    self.cmbLanguage.setFont(Config.font)
    self.lsvSource.setFont(Config.font)
    
    self.parentRecord=parentRecord
    
    self.cmbLanguageProxy=comboProxy( comboBox=self.cmbLanguage
                                    , tableName="lng_language"
                                    , currentKey=parentRecord.languagenr
                                     )
    self.lsvSourceProxy=listViewProxy( listView=self.lsvSource, tableName="lng_lex"
                                     , headers=["form", "glosse", "language"])

    self.connect(self.lsvSourceProxy, PYSIGNAL("sigItemSelected"), self.slotItemChosen)
    self.connect(self.bnFilter, SIGNAL("clicked()"), self.refreshSource)
    self.connect(self.buttonHelp, SIGNAL("clicked()"), self.slotHelp)
    
  def slotHelp(self):
    QMessageBox.about(self, "Picking a lexeme to go with a morpheme",
"""
A lot of morphemes have a direct representation in the lexicon. You won't
find a plural suffix in the lexicon, but the name of an object will have
an entry. This dialog is used to pick the lexical entry that's the same
as the morpheme you're editing. (Of course, one day, Kura will be able to
do the groundwork for you, leaving you to dither over the more specific items.)

You might also want to pick a lexical item from another language, for instance,
in the case of loanwords.
"""    )
    
  
  def refreshSource(self):
    rows=Config.app.getObjects("lng_lex", form=str(self.txtForm.text())
                                        , phonetic_form=str(self.txtPhoneticForm.text())
                                        , glosse=str(self.txtGlosse.text())
                                        , languagenr=self.cmbLanguageProxy.currentKey()
                                        )
    #
    # Get record from child languages
    #
    if self.chkChildrenIncluded.isChecked()==TRUE:
      languageRec=Config.app.createObject("lng_language", languagenr=self.cmbLanguageProxy.currentKey())
      childLanguages=languageRec.getChildLanguages()
      for language in childLanguages:
        rows=rows+Config.app.getObjects("lng_lex", form=str(self.txtForm.text())
                                        , phonetic_form=str(self.txtPhoneticForm.text())
                                        , glosse=str(self.txtGlosse.text())
                                        , languagenr=language.languagenr
                                        )

    self.lsvSourceProxy.refreshRows(rows)

  def slotItemChosen(self, item, record):
    self.accept()

  def accept(self):
    try:
      self.masterRecord=self.lsvSourceProxy.currentRecord()
      frmLexChooser.accept(self)
    except:
      frmLexChooser.reject(self)


__copyright__="""
/***************************************************************************
    copyright            : (C) 2000 by Boudewijn Rempt 
                           see copyright notice for license
    email                : boud@rempt.xs4all.nl
    Revision             : $Revision: 1.4 $
    Last edited          : $Date: 2001/01/26 20:02:17 $
    
    CVS Log:         
    $Log: dlglexchooser.py,v $
    Revision 1.4  2001/01/26 20:02:17  boud
    Move to dialog modelessness.

    Revision 1.3  2001/01/15 20:21:09  boud
    Added import/export filters, bugfixes.

    Revision 1.2  2001/01/08 20:55:06  boud
    Cleanup for version 1.0

 ***************************************************************************/
"""
