from qt             import *

from dbobj.dbobj    import dbError

from frmlexrelation import frmLexRelation
from kuracomboproxy import comboProxy

from resource       import *
from kuralib.config import Config

class listViewProxy(QObject):

  def __init__(self, listView, tableName, headers):
    QObject.__init__(self)
    self.listView=listView
    self.tableName=tableName
    self.rows={}
    self.headers=headers
  
    self.connect(self.listView, SIGNAL("doubleClicked(QListViewItem *)")
                     , self.slotItemSelected)
                     
  def slotItemSelected(self):
    self.emit(PYSIGNAL("sigItemSelected"),
                ( self.rows[self.listView.currentItem()]
                , self.listView.currentItem())
             )
    
  def slotAddItem(self, rec, otherLvi=None):
    """
      Add a record to the listview and the cache.
    """
    lvi=QListViewItem(self.listView)
    col=0
    for fieldname in self.headers:
      lvi.setText(col, rec.getFieldValue(fieldname))
      col=col+1   
    self.rows[lvi]=rec
    
    if otherLvi!=None:
      self.emit(PYSIGNAL("sigItemAdded"), (rec, otherLvi))

  def slotDeleteItem(self, rec, lvi):
    del self.rows[lvi]
    self.listView.takeItem(lvi)

  def refresh(self, searchRec):
    self.listView.clear()
    self.rows={}
    rows=Config.app.getObjects(self.tableName, fields=searchRec.getFields())
    for row in rows:
      self.slotAddItem(row)

  def refreshRows(self, rows):
    self.listView.clear()
    self.rows={}
    for row in rows:
      self.slotAddItem(row)

class dlgLexRelation(frmLexRelation):

  def __init__(self, parent, parentRecord):
  
    frmLexRelation.__init__(self, parent=parent, name="dlgLexRel", modal=FALSE)
    
    self.txtForm.setFont(Config.font)
    self.txtPhoneticForm.setFont(Config.font)
    self.txtGlosse.setFont(Config.font)
    self.cmbLanguage.setFont(Config.font)
    self.lsvChosen.setFont(Config.font)
    self.lsvSource.setFont(Config.font)
    self.cmbRelationCode.setFont(Config.font)
    
    self.parentRecord=parentRecord
    
    self.cmbLanguageProxy=comboProxy( comboBox=self.cmbLanguage
                                    , tableName="lng_language"
                                    , currentKey=parentRecord.languagenr
                                     )
    self.cmbRelationCodeProxy=comboProxy( comboBox=self.cmbRelationCode
                                        , tableName="lng_lxlxrelcode"
                                        )
    self.lsvSourceProxy=listViewProxy( listView=self.lsvSource
                                     , tableName="lng_lex"
                                     , headers=["form", "glosse", "language"])
    self.lsvChosenProxy=listViewProxy( listView=self.lsvChosen
                                     , tableName="lng_lex_lex"
                                     , headers=["form_2","relation"])

    
    self.connect(self.bnFilter, SIGNAL("clicked()")
                              , self.refreshSource)
    self.connect(self.lsvSourceProxy, PYSIGNAL("sigItemSelected")
                                    , self.convertLexemeToLexLex)
    self.connect(self.lsvSourceProxy, PYSIGNAL("sigItemAdded")
                                    , self.lsvChosenProxy.slotDeleteItem)
    self.connect(self.lsvChosenProxy, PYSIGNAL("sigItemSelected")
                                    , self.convertLexLexToLexeme)
    self.connect(self.lsvChosenProxy, PYSIGNAL("sigItemAdded")
                                    , self.lsvSourceProxy.slotDeleteItem)
    self.connect(self.buttonHelp, SIGNAL("clicked()")
                                , self.slotHelp)
    
  def slotHelp(self):
    QMessageBox.about(self, "Adding sets of lexemes",
"""
Using this dialog sets of lexemes can be added to the set of lexemes that are
in some way related to the lexeme you're editing in the dialog box under this 
one.

Enter some filter expressions in the box top left - use % for bits you want the
system to fill in. Then press the filter button. The list bottom left is filled
with possibles. Choose a default relation type from the drop-down list, and
double-click on the items you want to add. Double-click on added items to
remove them.
"""    )
    
  def convertLexemeToLexLex(self, lexRec, lvi):
    lexLexRec=Config.app.createObject("lng_lex_lex"
                           , lexnr_1=self.parentRecord.lexnr
                           , form_1=self.parentRecord.form
                           , lexnr_2=lexRec.lexnr
                           , form_2=lexRec.form
                           , lxlxrelcode=self.cmbRelationCodeProxy.currentKey()
                           , relation=self.cmbRelationCodeProxy.currentText()
                           , usernr=Config.usernr
                           )
    self.lsvChosenProxy.slotAddItem(lexLexRec, lvi)
    
  def convertLexLexToLexeme(self, lxlxRec, lvi):
    lexemeRec=Config.app.getObject("lng_lex", lexnr=lxlxRec.lexnr_2)
    self.lsvSourceProxy.slotAddItem(lexemeRec, lvi)
  
  
  def refreshSource(self):
    rows=Config.app.getObjects("lng_lex"
                              , form=str(self.txtForm.text())
                              , phonetic_form=str(self.txtPhoneticForm.text())
                              , glosse=str(self.txtGlosse.text())
                              , languagenr=self.cmbLanguageProxy.currentKey()
                              )
    #
    # Get record from child languages
    #
    if self.chkChildrenIncluded.isChecked()==TRUE:
      languageRec=Config.app.createObject("lng_language"
                        , languagenr=self.cmbLanguageProxy.currentKey())
      childLanguages=languageRec.getChildLanguages()
      for language in childLanguages:
        rows=rows+Config.app.getObjects("lng_lex"
                              , form=str(self.txtForm.text())
                              , phonetic_form=str(self.txtPhoneticForm.text())
                              , glosse=str(self.txtGlosse.text())
                              , languagenr=language.languagenr
                              )

    #
    # FIXME: filter already chosen items out!
    #
    self.lsvSourceProxy.refreshRows(rows)

  def accept(self):
    for rec in self.lsvChosenProxy.rows.values():
      try:
        if rec.lxlxnr==None:
          rec.insert()
        else:
          rec.update()
      except dbError, dberr:
        QMessageBox.information(self, "Kura Error"
                                , dberr.errorMessage)
      else:    
        self.emit(PYSIGNAL("sigAcceptData"),())
        frmLexRelation.accept(self)

__copyright__="""
/***************************************************************************
    copyright            : (C) 2000 by Boudewijn Rempt 
                           see copyright notice for license
    email                : boud@rempt.xs4all.nl
    Revision             : $Revision: 1.3 $
    Last edited          : $Date: 2001/01/26 20:02:17 $
    
    CVS Log:         
    $Log: dlglexrelation.py,v $
    Revision 1.3  2001/01/26 20:02:17  boud
    Move to dialog modelessness.

    Revision 1.2  2001/01/08 20:55:06  boud
    Cleanup for version 1.0

 ***************************************************************************/
"""
