import sys

from qt import *

from kuralib.config import Config

from kuragui.guilistview   import guiListView
from kuragui.guidetaillist import guiDetailList
from kuragui.constants     import *

from frmstylecode        import frmStylecode
from resource import *

class dlgStyleCode(frmStylecode):

  def __init__(self, app, parent, title, firstTabTitle, record, mode, tableDef, showChildren=FALSE):
    frmStylecode.__init__(self, parent=parent, modal=TRUE)
    self.record=record
    self.mode=mode
    self.txtStylecode.setText(self.record.stylecode)
    self.txtStylecode.setFont(Config.font)
    
    self.txtDescription.setText(self.record.description)
    self.txtDescription.setFont(Config.font)
    
    if self.mode==SEARCH:
      self.chkShowIfNull.setTristate(TRUE)
      self.chkRespectNewline.setTristate(TRUE)

    self.chkShowIfNull.setChecked(int(record.showifnull))
    self.chkRespectNewline.setChecked(int(record.wordwrap))
     
    self.font=QFont(record.font, int(record.size), int(record.weight), int(record.italic), int(record.charset))
    self.txtFont.setText(record.font)
    self.lblFont.setText(u"Lorem ipsem unicode: \u0255u\u0256\u0257\u0258\u0FA0")
    self.lblFont.setFont(self.font)
    
    self.connect(self.bnFont, SIGNAL("clicked()"), self.slotGetFont)
    
  def slotGetFont(self):
    font, OK=QFontDialog.getFont(self.font, self)
    if OK:
      self.font=font
      
      self.lblFont.setFont(font)
      self.txtFont.setText(font.family())
      
      self.record.font=unicode(font.family())
      self.record.size=int(font.pointSize())
      self.record.weight=int(font.weight())
      self.record.italic=int(font.italic())
      self.record.charset=int(font.charSet())

  def apply(self):
    try:
      self.record.stylecode=unicode(self.txtStylecode.text())
      self.record.description=unicode(self.txtDescription.text())
      self.record.showifnull=self.chkShowIfNull.isChecked()
      self.record.wordwrap=self.chkRespectNewline.isChecked()
      if self.mode==INSERT:
        self.record.insert()
      elif self.mode==UPDATE:
        self.record.update()

      return TRUE
    except:
      QMessageBox.information(self, "Kura Error while inserting", "Something went horribly wrong, and I don't know what.")
      return FALSE
    
  def accept(self):
    if self.apply()==TRUE:
      frmStylecode.accept(self)
    
  def getMasterRecord(self):
    return self.record    
     
def main():

  try:
    from kuralib import lngapp
  except:
    sys.path.append("..")
    from kuralib import lngapp

  from kuralib.lng_lex import *

  qapp=QApplication(sys.argv)
  app=lngapp.lngApp(host="localhost", user="boud", database="lng")
  toplevel=guiListView( app
                      , tableName="lng_stylecode"
                      , searchRec=app.createObject('lng_stylecode')
                      , dlgForm=dlgStyleCode
                      , dlgSearch=None
                      , parent=None
                      )
  toplevel.show()
  qapp.connect(qapp, SIGNAL('lastWindowClosed()'), qapp, SLOT('quit()'))
  qapp.exec_loop()
  
if __name__=="__main__":
  if len(sys.argv)>1:
    if sys.argv[1]=='-p':
      import profile
      profile.run('main()')
  else:
    main()

__copyright__="""
/***************************************************************************
    copyright            : (C) 2000 by Boudewijn Rempt 
                           see copyright notice for license
    email                : boud@rempt.xs4all.nl
    Revision             : $Revision: 1.3 $
    Last edited          : $Date: 2001/01/15 20:21:09 $
    
    CVS Log:         
    $Log: dlgstylecode.py,v $
    Revision 1.3  2001/01/15 20:21:09  boud
    Added import/export filters, bugfixes.

    Revision 1.2  2001/01/08 20:55:06  boud
    Cleanup for version 1.0

 ***************************************************************************/
"""
