# Python libs

from os import *
from _mysql import OperationalError
# include files for QT
from qt import *

# application specific includes
from resource import *
from kuralib import lngapp

# Configuration settings
from kuralib.config import Config
from kuralib import config

from dbobj.dbexceptions import *

# import gui resources
from kuragui import guiaction
from kuragui.guilistview import guiListView

# import special main views
from kuratextlistview import kuraTextListView
from charmap.mainwin import QCharMap

# import dialogs
import frmlogin
import dlgpreferences


def Icon(pixmap):
  return QIconSet(QPixmap(path.join(environ["KURADIR"], "pixmaps", pixmap)))

class KuraPanel(QLabel):

  def __init__(self, *args):
    apply(QLabel.__init__,(self, ) + args)
    self.setFrameShape(QLabel.Panel)
    self.setSizePolicy(QSizePolicy(1,0,self.sizePolicy().hasHeightForWidth()))
    self.setFont(Config.font)

  def setText(self, text):
    QLabel.setText(self, " " + text + " " )

class KuraStatusBar(QStatusBar):

  def __init__(self, *args):
    apply(QStatusBar.__init__,(self, ) + args)
    self.lblUser=KuraPanel(self)
    self.setUserLabel(Config.usernr)
    self.addWidget(self.lblUser, 0, FALSE)
    self.lblProject=KuraPanel(self)
    self.setProjectLabel(Config.projectnr)
    self.addWidget(self.lblProject, 0, FALSE)
    self.lblLanguage=KuraPanel(self)
    self.setlanguageLabel(Config.languagenr)
    self.addWidget(self.lblLanguage, 0, FALSE)

  
  def setUserLabel(self, usernr):
    try:
      username="User: " + Config.app.getObject("lng_user"
             , usernr=usernr).getFieldValue("name")
    except Exception, err:
      username="No current user"
    self.lblUser.setText(username)
    
  def setProjectLabel(self, projectnr):
    try:
      project="Project: " + Config.app.getObject( "lng_project"
           , projectnr=projectnr).getFieldValue("description")
    except Exception, err:
      project="No current project"
    self.lblProject.setText(project)

  def setlanguageLabel(self, languagenr):
    try:
      language="Language: " + Config.app.getObject( "lng_language"
                , languagenr=languagenr).getFieldValue("language")
    except Exception, err:
      language="No current language"
    self.lblLanguage.setText(language)
  
class KuraWindow(QMainWindow):

  def __init__(self, *args):
    apply(QMainWindow.__init__,(self,) + args)

    self.windows=[]

    self.initActions()
    self.initMenuBar()
    self.initToolBar()
    self.initStatusBar()

    self.setStyle(Config.currentStyle)
    self.__actions["FILE_SAVE"].setEnabled(FALSE)
    self.file_menu.insertSeparator()
    self.__actions["FILE_PRINT"].setEnabled(FALSE)
    self.view=None
    self.initView()

  def initMenuBar(self):
    self.file_menu=QPopupMenu()
    self.__actions["FILE_NEW_WINDOW"].addTo(self.file_menu)
    self.file_menu.insertSeparator()
    self.__actions["FILE_NEW"].addTo(self.file_menu)
    self.__actions["FILE_OPEN"].addTo(self.file_menu)
    self.__actions["FILE_SAVE"].addTo(self.file_menu)
    self.file_menu.insertSeparator()
    self.__actions["FILE_PRINT"].addTo(self.file_menu)
    self.file_menu.insertSeparator()
    self.__actions["FILE_CONNECT"].addTo(self.file_menu)
    self.__actions["OPTIONS_PREFERENCES"].addTo(self.file_menu)
    self.file_menu.insertSeparator()
    self.__actions["FILE_QUIT"].addTo(self.file_menu)

    # menuBar entry self.edit_menu
    self.edit_menu = QPopupMenu()
    #self.__actions["EDIT_CUT"].addTo(self.edit_menu)
    #self.__actions["EDIT_COPY"].addTo(self.edit_menu)
    #self.__actions["EDIT_PASTE"].addTo(self.edit_menu)
    #self.edit_menu.insertSeparator()
    self.__actions["EDIT_FIND"].addTo(self.edit_menu)
    self.edit_menu.insertSeparator()
    self.__actions["EDIT_DELETE"].addTo(self.edit_menu)
    self.edit_menu.insertSeparator()
    self.__actions["EDIT_CHARMAP"].addTo(self.edit_menu)
    
    # menuBar entry self.view_menu
    self.view_menu = QPopupMenu()
    self.__actions["lng_lex"].addTo(self.view_menu)
    self.__actions["lng_recording"].addTo(self.view_menu)
    self.__actions["lng_scan"].addTo(self.view_menu)
    self.__actions["lng_text"].addTo(self.view_menu)

    self.admin_menu = QPopupMenu()
    self.__actions["lng_project"].addTo(self.admin_menu)
    self.__actions["lng_language"].addTo(self.admin_menu)
    self.__actions["lng_user"].addTo(self.admin_menu)
    self.__actions["lng_affiliationcode"].addTo(self.admin_menu)
    self.admin_menu.insertSeparator()
    #self.__actions["lng_document"].addTo(self.admin_menu)
    #self.__actions["lng_linkcode"].addTo(self.admin_menu)
    self.__actions["lng_reference"].addTo(self.admin_menu)
    self.__actions["lng_categorycode"].addTo(self.admin_menu)

    self.configuration_menu = QPopupMenu()
    self.__actions["lng_tag"].addTo(self.configuration_menu)
    self.__actions["lng_tagtypecode"].addTo(self.configuration_menu)
    self.__actions["lng_elementtypecode"].addTo(self.configuration_menu)    
    self.__actions["lng_stylecode"].addTo(self.configuration_menu)    
    self.__actions["lng_tagdomain"].addTo(self.configuration_menu)
    self.__actions["lng_lxlxrelcode"].addTo(self.configuration_menu)    

    self.menuBar().insertItem("&File", self.file_menu)
    self.menuBar().insertItem("&Edit", self.edit_menu)
    self.menuBar().insertItem("&Documents", self.view_menu)
    self.menuBar().insertItem("&Administration", self.admin_menu)
    self.menuBar().insertItem("&Configuration", self.configuration_menu)

    self.help = QPopupMenu(self)
    self.menuBar().insertSeparator()
    self.menuBar().insertItem('&Help', self.help)

    self.help.insertItem('&About', self.slotAbout, Qt.Key_F1)
    self.help.insertItem('About &Qt', self.aboutQt)

  def initToolBar(self):

    self.toolBar=QToolBar(self,'Main')
    self.buttons=[]
    self.__actions["FILE_NEW"].addTo(self.toolBar)
    self.__actions["FILE_OPEN"].addTo(self.toolBar)
    #self.__actions["FILE_SAVE"].addTo(self.toolBar)
    #self.__actions["FILE_PRINT"].addTo(self.toolBar)
    #self.toolBar.addSeparator()
    #self.__actions["EDIT_CUT"].addTo(self.toolBar)
    #self.__actions["EDIT_COPY"].addTo(self.toolBar)
    #self.__actions["EDIT_PASTE"].addTo(self.toolBar)
    self.toolBar.addSeparator()
    self.__actions["EDIT_CHARMAP"].addTo(self.toolBar)
    self.toolBar.addSeparator()
    self.__actions["EDIT_FIND"].addTo(self.toolBar)
    self.toolBar.addSeparator()
    self.__actions["EDIT_DELETE"].addTo(self.toolBar)
    self.toolBar.addSeparator()
    self.__actions["FILE_QUIT"].addTo(self.toolBar)

  def initStatusBar(self):
    self.statusBar=KuraStatusBar(self)

  def setStyle(self, style):
    Config.currentStyle=style
    if style=="Platinum":
      newstyle=QPlatinumStyle()
    elif style=="Motif":
      newstyle=QMotifStyle(TRUE)
    elif style=="Motif+":
      newstyle=QMotifPlusStyle(FALSE)
    #elif style=="SGI":
    #  newstyle=QSGIStyle(TRUE)
    elif style=="CDE":
      newstyle=QCDEStyle(TRUE)
    elif style=="Windows":
      newstyle=QWindowsStyle()
    else:
      newstyle=QPlatinumStyle()
    
    qApp.setStyle(newstyle)
      
  def initView(self):
      
    if Config.app != None and Config.currentTableName != None:
      try:
        self.openView(Config.currentTableName)
      except:
        print "Something is wrong with you configuration file (~/.kurarc).",
        print "Please remove it."

    else:
      self.setCaption("Kura")
    
  def openView(self, tableName, searchRec=None):

    try:
      self.view.saveHeaders()
    except Exception, err:
      pass

    if searchRec==None:
      if Config.useDefaultForSearch==TRUE:
        searchRec=Config.app.createDefaultObject(tableName)
      else:
        searchRec=Config.app.createObject(tableName)
    Config.currentTableName=tableName
      
    if tableName=="lng_text":
      self.view=kuraTextListView(parent=self, searchRec=searchRec)
    else:  
      self.view=guiListView( app=Config.app
                        , tableName=tableName 
                        , searchRec=searchRec
                        , dlgForm=self.__actions[tableName].dlgForm
                        , dlgSearch=self.__actions[tableName].dlgSearch
                        , parent=self
                        )
                        
    self.setCentralWidget(self.view)
    self.view.show()    
    self.view.setFocus()
    self.setCaption("Kura: " +  Config.app.getTableLable(tableName) )
    
  def enableCommand(self, action):
    self.__actions[action].setEnabled(TRUE)

  def disableCommand(self, action):
    self.__actions[action].setEnabled(FALSE)
    
  def openDocumentFile(self, _cmdl):
    self.view.Open()
#
# Events
#     

  def closeEvent(self, e):
    try:
      self.view.saveHeaders()
    except:
      pass
    Config.app_x=self.x()
    Config.app_y=self.y()
    Config.app_w=self.width()
    Config.app_h=self.height()
    config.saveConfig()
    e.accept()
  
#
# SLOT IMPLEMENTATION
#

  def slotAbout(self):
    QMessageBox.about(self, 'Kura, the linguistics database',
"""Kura is a database for linguistic data: texts, recordings,
manuscripts, lexical item, grammatical data and etymological
relations. The data can be edited in this application and presented
on the web using the Kuraserver.

Version %s

(c) 1999, 2000. Boudewijn Rempt
""" % VERSION)    

  def aboutQt(self):
    QMessageBox.aboutQt(self, 'Kura, the linguistics database.')


  def slotFileNewWindow(self):
    window=KuraWindow()
    self.windows.append(window)
    window.show()
  
  def slotFileNew(self):
    self.view.New()

  def slotFileOpen(self):
    self.view.Open()

  def slotFilePrint(self):
    printer=QPrinter()
    if printer.setup(self)==TRUE:
      self.view.printView(printer)

  def slotConnect(self):

    d = frmlogin.frmLogin(parent=self, modal=TRUE)

    d.txtUsername.setText(Config.dbuser)
    d.txtPassword.setText(Config.password)
    d.txtDatabase.setText(Config.database)
    d.txtHost.setText(Config.host)
    # intentionally modal
    if d.exec_loop() == 1: # accepted
      dbuser=str(d.txtUsername.text())
      password=str(d.txtPassword.text())
      database=str(d.txtDatabase.text())
      host=str(d.txtHost.text())
      if (dbuser<>Config.dbuser or 
        password<>Config.password or 
        database<>Config.database or 
        host<>Config.host):
        Config.dbuser=dbuser
        Config.password=password
        Config.database=database
        Config.host=host
        try:
          if Config.app==None:
            Config.app=lngapp.lngApp(user=dbuser
                              ,database=database
                              ,host=host
                              ,password=password
                              )
          else:
               Config.app.reconnect( user=dbuser
                                   , database=database
                                   , host=host
                                   , password=password
                                   )

        except OperationalError, error:
          QMessageBox.critical(self, "Database error"
                                  , str(error))
            
      else:
        print "Nothing changed"
    else:
      print "Cancel"
    
    d=None

  def slotFileQuit(self):
    self.close()

  def slotEditCut(self):
    pass

  def slotEditCopy(self):
    pass
    
  def slotEditPaste(self):
    pass

  def slotEditDelete(self):
    self.view.Delete()
    
  def slotEditFind(self):
    self.view.Find()
    
  def slotEditCharmap(self):
    window=QCharMap()
    self.windows.append(window)
    window.show()
    
    
  def slotPreferences(self):
    d = dlgpreferences.dlgPreferences(parent=self)
    # intentionally modal
    if d.exec_loop() == 1: # accepted
      # save in Config object
      d.savePreferences()
      
      # alter statusbar
      self.statusBar.setUserLabel(Config.usernr)
      self.statusBar.setProjectLabel(Config.projectnr)
      self.statusBar.setlanguageLabel(Config.languagenr)
      
      # set widgetstyle
      style=str(d.cmbStyle.currentText())
      if style!=Config.currentStyle:
        self.setStyle(style)
    else:
      print "Cancel"
    d=None

#
# Callbacks
#
  def initActions(self):
    self.__actions={}
    
    #
    # Create actions
    #
    guiAction=guiaction.guiAction
    self.__actions["EDIT_COPY"]=guiAction(self)
    self.__actions["EDIT_CUT"]=guiAction(self)
    self.__actions["EDIT_DELETE"]=guiAction(self)
    self.__actions["EDIT_FIND"]=guiAction(self)
    self.__actions["EDIT_PASTE"]=guiAction(self)
    self.__actions["EDIT_CHARMAP"]=guiAction(self)
    self.__actions["FILE_CLOSE"]=guiAction(self)
    self.__actions["FILE_CONNECT"]=guiAction(self)
    self.__actions["FILE_NEW"]=guiAction(self)
    self.__actions["FILE_NEW_WINDOW"]=guiAction(self)
    self.__actions["FILE_OPEN"]=guiAction(self)
    self.__actions["FILE_PRINT"]=guiAction(self)
    self.__actions["FILE_QUIT"]=guiAction(self)
    self.__actions["FILE_SAVE"]=guiAction(self)
    self.__actions["lng_affiliationcode"]=guiAction(self)
    self.__actions["lng_document"]=guiAction(self)
    self.__actions["lng_language"]=guiAction(self)
    self.__actions["lng_linkcode"]=guiAction(self)
    self.__actions["lng_lxlxrelcode"]=guiAction(self)
    self.__actions["OPTIONS_PREFERENCES"]=guiAction(self)
    self.__actions["lng_project"]=guiAction(self)
    self.__actions["lng_categorycode"]=guiAction(self)
    self.__actions["lng_reference"]=guiAction(self)
    self.__actions["lng_tag"]=guiAction(self)
    self.__actions["lng_tagdomain"]=guiAction(self)
    self.__actions["lng_tagtypecode"]=guiAction(self)
    self.__actions["lng_stylecode"]=guiAction(self)    
    self.__actions["lng_elementtypecode"]=guiAction(self)    
    self.__actions["lng_user"]=guiAction(self)
    self.__actions["lng_lex"]=guiAction(self)
    self.__actions["lng_recording"]=guiAction(self)
    self.__actions["lng_scan"]=guiAction(self)
    self.__actions["lng_text"]=guiAction(self)

    #
    # Set the (table)name for the activatedName pysignal
    #    
    for name, action in self.__actions.items():
      action.setName(name)
    #
    # Set menu texts
    #
    self.__actions["EDIT_COPY"].setMenuText("&Copy")
    self.__actions["EDIT_CUT"].setMenuText("Cu&t")
    self.__actions["EDIT_DELETE"].setMenuText("&Delete")
    self.__actions["EDIT_FIND"].setMenuText("&Find")
    self.__actions["EDIT_PASTE"].setMenuText("&Paste")
    self.__actions["EDIT_CHARMAP"].setMenuText("Unicode character map")
    self.__actions["FILE_CONNECT"].setMenuText("&Connect...")
    self.__actions["FILE_NEW"].setMenuText("&New...")
    self.__actions["FILE_NEW_WINDOW"].setMenuText("New &Window")
    self.__actions["FILE_OPEN"].setMenuText("&Open...")
    self.__actions["FILE_PRINT"].setMenuText("&Print...")
    self.__actions["FILE_QUIT"].setMenuText("&Quit")
    self.__actions["FILE_SAVE"].setMenuText("&Save")
    self.__actions["OPTIONS_PREFERENCES"].setMenuText("Preferences...")
    self.__actions["lng_affiliationcode"].setMenuText("Affiliation&s")
    self.__actions["lng_categorycode"].setMenuText("Reference Categories")
    self.__actions["lng_document"].setMenuText("&Document")
    self.__actions["lng_language"].setMenuText("&Language")
    self.__actions["lng_lex"].setMenuText("&Lexicon")
    self.__actions["lng_linkcode"].setMenuText("&Link types")
    self.__actions["lng_lxlxrelcode"].setMenuText("&Lexical relations")
    self.__actions["lng_project"].setMenuText("Pro&ject")
    self.__actions["lng_recording"].setMenuText("&Recording")
    self.__actions["lng_reference"].setMenuText("&References")
    self.__actions["lng_scan"].setMenuText("&Scan")
    self.__actions["lng_tag"].setMenuText("Ta&gs")
    self.__actions["lng_tagdomain"].setMenuText("Tag domains")
    self.__actions["lng_tagtypecode"].setMenuText("Tag categories")
    self.__actions["lng_elementtypecode"].setMenuText("Element types")
    self.__actions["lng_stylecode"].setMenuText("Rendering styles")    
    self.__actions["lng_text"].setMenuText("&Text")
    self.__actions["lng_user"].setMenuText("&User")
    #
    # Set tooltips
    #
    self.__actions["EDIT_COPY"].setToolTip("Copies the selected section to the clipboard")
    self.__actions["EDIT_CUT"].setToolTip("Cuts the selected section and puts it to the clipboard")
    self.__actions["EDIT_DELETE"].setToolTip("Delete the selected record")
    self.__actions["EDIT_FIND"].setToolTip("Search in ")
    self.__actions["EDIT_PASTE"].setToolTip("Pastes the clipboard contents to actual position")
    self.__actions["EDIT_CHARMAP"].setToolTip("Opens the Unicode character selection window")
    self.__actions["FILE_CONNECT"].setToolTip("Connect to the Kura database")
    self.__actions["FILE_NEW"].setToolTip("Creates a new record")
    self.__actions["FILE_NEW_WINDOW"].setToolTip("Opens a new Kura window")
    self.__actions["FILE_OPEN"].setToolTip("Edit selected record")
    self.__actions["FILE_PRINT"].setToolTip("Prints the current document")
    self.__actions["FILE_QUIT"].setToolTip("Quit")
    self.__actions["lng_affiliationcode"].setToolTip("Open the list of affilications")
    self.__actions["lng_document"].setToolTip("Open the list of link types")
    self.__actions["lng_language"].setToolTip("Open the list of languages")
    self.__actions["lng_linkcode"].setToolTip("Open the list of references")
    self.__actions["lng_lxlxrelcode"].setToolTip("Open the list of lexical relation types")
    self.__actions["OPTIONS_PREFERENCES"].setToolTip("User preferences")
    self.__actions["lng_project"].setToolTip("Open the list of projects")
    self.__actions["lng_categorycode"].setToolTip("Open the list of reference categories")
    self.__actions["lng_reference"].setToolTip("Open the list of documents")
    self.__actions["lng_tag"].setToolTip("Open the list of tags")
    self.__actions["lng_tagtypecode"].setToolTip("Open the list of tag types")
    self.__actions["lng_elementtypecode"].setToolTip("Open the list of element types")
    self.__actions["lng_stylecode"].setToolTip("Open the list of tag styles")
    self.__actions["lng_user"].setToolTip("Open the list of users")
    self.__actions["lng_lex"].setToolTip("Open the lexicon")
    self.__actions["lng_recording"].setToolTip("Open the list of recordings")
    self.__actions["lng_scan"].setToolTip("Open the list of scanned images")
    self.__actions["lng_text"].setToolTip("Open the list of texts")
    #
    # Set pixmaps
    #
    self.__actions["EDIT_COPY"].setIconSet(Icon("editcopy.xpm"))
    self.__actions["EDIT_CUT"].setIconSet(Icon("editcut.xpm"))
    self.__actions["EDIT_DELETE"].setIconSet(Icon("mini-cross.xpm"))
    self.__actions["EDIT_FIND"].setIconSet(Icon("search.xpm"))
    self.__actions["EDIT_PASTE"].setIconSet(Icon("editpaste.xpm"))
    self.__actions["EDIT_CHARMAP"].setIconSet(Icon("unicode.xpm"))
    self.__actions["FILE_CONNECT"].setIconSet(Icon("mini-connect.xpm"))
    self.__actions["FILE_NEW"].setIconSet(Icon("filenew.xpm"))
    self.__actions["FILE_NEW_WINDOW"].setIconSet(Icon("windows.xpm"))
    self.__actions["FILE_OPEN"].setIconSet(Icon("fileopen.xpm"))
    self.__actions["FILE_PRINT"].setIconSet(Icon("fileprint.xpm"))
    self.__actions["FILE_QUIT"].setIconSet(Icon("exit.xpm"))
    self.__actions["FILE_SAVE"].setIconSet(Icon("filefloppy.xpm"))
    
    #
    # Set forms
    #
    from dlgtagtypecode import dlgTagTypeCode
    self.__actions["lng_tagtypecode"].setSearchForm(dlgTagTypeCode)
    self.__actions["lng_tagtypecode"].setForm(dlgTagTypeCode)
    from dlgstylecode import dlgStyleCode
    self.__actions["lng_stylecode"].setSearchForm(dlgStyleCode)
    self.__actions["lng_stylecode"].setForm(dlgStyleCode)
   
    from dlglexeme import dlgLexeme
    self.__actions["lng_lex"].setForm(dlgLexeme)

    #
    # Set slots
    #
    QObject.connect(self.__actions["FILE_NEW_WINDOW"], SIGNAL("activated()"), self.slotFileNewWindow )
    QObject.connect(self.__actions["FILE_NEW"], SIGNAL("activated()"), self.slotFileNew)
    QObject.connect(self.__actions["FILE_OPEN"], SIGNAL("activated()"), self.slotFileOpen)
    QObject.connect(self.__actions["FILE_PRINT"], SIGNAL("activated()"), self.slotFilePrint)
    QObject.connect(self.__actions["FILE_CONNECT"], SIGNAL("activated()"), self.slotConnect)
    QObject.connect(self.__actions["FILE_QUIT"], SIGNAL("activated()"), self.slotFileQuit)
    QObject.connect(self.__actions["EDIT_CUT"], SIGNAL("activated()"), self.slotEditCut)
    QObject.connect(self.__actions["EDIT_COPY"], SIGNAL("activated()"), self.slotEditCopy)
    QObject.connect(self.__actions["EDIT_PASTE"], SIGNAL("activated()"), self.slotEditPaste)
    QObject.connect(self.__actions["EDIT_DELETE"], SIGNAL("activated()"), self.slotEditDelete)
    QObject.connect(self.__actions["EDIT_FIND"], SIGNAL("activated()"), self.slotEditFind)
    QObject.connect(self.__actions["EDIT_CHARMAP"], SIGNAL("activated()"), self.slotEditCharmap)
    QObject.connect(self.__actions["lng_lex"], PYSIGNAL("activatedName"), self.openView)
    QObject.connect(self.__actions["lng_recording"], PYSIGNAL("activatedName"), self.openView)
    QObject.connect(self.__actions["lng_scan"], PYSIGNAL("activatedName"), self.openView)
    QObject.connect(self.__actions["lng_text"], PYSIGNAL("activatedName"), self.openView)
    QObject.connect(self.__actions["lng_project"], PYSIGNAL("activatedName"), self.openView)
    QObject.connect(self.__actions["lng_language"], PYSIGNAL("activatedName"), self.openView)
    QObject.connect(self.__actions["lng_user"], PYSIGNAL("activatedName"), self.openView)
    QObject.connect(self.__actions["lng_document"], PYSIGNAL("activatedName"), self.openView)
    QObject.connect(self.__actions["lng_lxlxrelcode"], PYSIGNAL("activatedName"), self.openView)
    QObject.connect(self.__actions["lng_linkcode"], PYSIGNAL("activatedName"), self.openView)
    QObject.connect(self.__actions["lng_reference"], PYSIGNAL("activatedName"), self.openView)
    QObject.connect(self.__actions["lng_categorycode"], PYSIGNAL("activatedName"), self.openView)
    QObject.connect(self.__actions["lng_tag"], PYSIGNAL("activatedName"), self.openView)
    QObject.connect(self.__actions["lng_tagtypecode"], PYSIGNAL("activatedName"), self.openView)
    QObject.connect(self.__actions["lng_elementtypecode"], PYSIGNAL("activatedName"), self.openView)
    QObject.connect(self.__actions["lng_stylecode"], PYSIGNAL("activatedName"), self.openView)
    QObject.connect(self.__actions["lng_tagdomain"], PYSIGNAL("activatedName"), self.openView)
    QObject.connect(self.__actions["lng_affiliationcode"], PYSIGNAL("activatedName"), self.openView)
    QObject.connect(self.__actions["OPTIONS_PREFERENCES"], SIGNAL("activated()"), self.slotPreferences)


__copyright__="""
/***************************************************************************
    copyright            : (C) 2000 by Boudewijn Rempt 
                           see copyright notice for license
    email                : boud@rempt.xs4all.nl
    Revision             : $Revision: 1.26 $
    Last edited          : $Date: 2001/02/01 19:53:36 $
    
    CVS Log:         
    $Log: kura.py,v $
    Revision 1.26  2001/02/01 19:53:36  boud
    Made more robust connecting code

    Revision 1.25  2001/02/01 19:29:44  boud
    Restored opening of texts.

    Revision 1.24  2001/01/31 20:04:36  boud
    Bugfixes.

    Revision 1.23  2001/01/30 20:04:42  boud
    Removed print statements.

    Revision 1.22  2001/01/30 19:43:02  boud
    Several small bugfixes.

    Revision 1.21  2001/01/30 18:41:06  boud
    Corrected bug in calling connection dialog.

    Revision 1.20  2001/01/30 18:10:08  boud
    Made dialogs non-modal, added statusbar, added charmap window.

    Revision 1.19  2001/01/26 20:02:17  boud
    Move to dialog modelessness.

    Revision 1.18  2001/01/24 19:18:47  boud
    Made more robust.

    Revision 1.17  2001/01/24 19:15:32  boud
    UI changes.

    Revision 1.16  2001/01/15 20:21:09  boud
    Added import/export filters, bugfixes.

    Revision 1.15  2001/01/08 20:55:06  boud
    Cleanup for version 1.0

 ***************************************************************************/
"""
