from kuragui.constants import *
from kuralib.config import Config
from qt import *

DOMAIN=0
VALUE=1
REFERENCE=2
NOTE=3


class kuraCmbTagValues(QComboBox):
  """
  
    kuraCmbTagValues is a combobox that shows all values that have
    been entered for a certain tag in the tag_domain table. Users
    can add new values here, but they will _not_ be autmatically
    added to tag_domain - unless they want to (configuration option!)
    
    Note: make this a what's this text.
    
    @param parent - the QWidget parent of this QWidget
    @param tag    - the tag where the list is based on
    @param        - tagTableName - lng_lex_tag, lng_element_tag etc.
  """

  def __init__(self, parent, tagTableName, tag=None, *args):
    QComboBox.__init__(self, parent, )
    self.setAutoCompletion(TRUE)
    self.setFont(Config.font)
    self.index_to_key={}
    self.key_to_index={}
    self.strlist=[]
    self.mode=None
    self.tagTableName=tagTableName
    if tag != None:
      self.slotRefresh(tag)
  
  
  def clear(self):
    QComboBox.clear(self)
    self.index_to_key={}
    self.key_to_index={}
    self.strlist=[]
      
  def slotRefresh(self, tag):
    self.clear()

    if tag==None:
      QComboBox.setEnabled(self, FALSE)
    else:
      
      tagType=Config.app.getObject("lng_tag", tag=tag).getTagTypeCode()
      
      if int(tagType.isdomain)==TRUE:
        self.mode=DOMAIN
        QComboBox.setEnabled(self, TRUE)
        QComboBox.setEditable(self, FALSE)

        rows=Config.app.getObjects("lng_tagdomain", tag=tag)
        for row in rows:
          self.insertItem(row.description) 
          index=self.count()-1
          self.index_to_key[index]=row.domainnr
          self.key_to_index[row.domainnr]=index

      elif int(tagType.isvalue)==TRUE:
        self.mode=VALUE
        QComboBox.setEnabled(self, TRUE)
        QComboBox.setEditable(self, TRUE)

        self.insertItem("<New Value>")
        
        if Config.ShowValueHint==TRUE:
          rows=Config.app.getObjects(self.tagTableName, tag=tag)
          self.strlist=["<New Value>"]
          for row in rows:
            if row.value not in self.strlist:
              self.strlist.append(row.value)
              self.insertItem(row.value)
            
            
      elif int(tagType.isreference)==TRUE:
        self.mode=REFERENCE
        QComboBox.setEnabled(self, TRUE)
        QComboBox.setEditable(self, FALSE)

        rows=Config.app.getObjects("lng_reference")
        for row in rows:
          self.insertItem(row.title + ", " + row.year + ", " + row.author) 
          index=self.count()-1
          self.index_to_key[index]=row.referencenr
          self.key_to_index[row.referencenr]=index

      else:
        QComboBox.setEnabled(self, FALSE)
        QComboBox.setEditable(self, FALSE)
    
  def slotSetCurrentItem(self, value):
   
    if self.mode==DOMAIN:
      if hasattr(self.key_to_index, value)==FALSE:
        return
      else:
        self.setCurrentItem(self.key_to_index[value])
        
    elif self.mode==VALUE:
      if Config.ShowValueHint==TRUE:
        if value in self.strlist:
          self.setCurrentItem(self.strlist.index(value))
          self.changeItem(value, self.currentItem())
        else:
          if self.currentText()=="<New Value>":
            self.changeItem(value, 0)
          else:
            self.insertItem(value, 0)
      else:
        self.changeItem(value, 0)
          
    elif self.mode==REFERENCE:
      if hasattr(self.key_to_index, value)==FALSE:
        return
      else:
        self.setCurrentItem(self.key_to_index[value])
    
  def currentKey(self):
    if self.mode==DOMAIN:
      return self.index_to_key[self.currentItem()]
    elif self.mode==VALUE:
      return unicode(self.currentText())
    elif self.mode==REFERENCE:
      return self.index_to_key[self.currentItem()]
    else:
      return None

__copyright__="""
/***************************************************************************
    copyright            : (C) 2000 by Boudewijn Rempt 
                           see copyright notice for license
    email                : boud@rempt.xs4all.nl
    Revision             : $Revision: 1.6 $
    Last edited          : $Date: 2001/01/30 20:04:42 $
    
    CVS Log:         
    $Log: kuracmbtagvalues.py,v $
    Revision 1.6  2001/01/30 20:04:42  boud
    Removed print statements.

    Revision 1.5  2001/01/08 20:55:06  boud
    Cleanup for version 1.0

 ***************************************************************************/
"""
