import sys

from qt import *
TRUE=1
FALSE=0
try:
  from kuralib.config import Config
except:
  sys.path.append("..")
  sys.path.append(".")
  from kuralib.config import Config

from dbobj.dbexceptions import dbRecordNotFoundException


from kurailcanvas import kuraIlCanvas

class kuraIlCanvasView(QCanvasView):
  
  def __init__(self, *args):
    apply(QCanvasView.__init__,(self, ) + args)
    self.setFocusPolicy(QWidget.StrongFocus)

  def drawCursor(self, item):
    self.cursorItem=QCanvasRectangle(self.canvas()) 
    self.cursorItem.setX(item.boundingRect().x() -2)
    self.cursorItem.setY(item.boundingRect().y() -2)
    self.cursorItem.setSize(item.boundingRect().width() + 4, item.boundingRect().height() + 4)
    
    self.cursorItem.setZ(-1.0)
    self.cursorItem.setPen(QPen(QColor(Qt.gray), 2, Qt.DashLine))
    self.cursorItem.show()
    self.canvas().update()
  
  def setCursor(self, item):
    self.currentItem=item
    try:
      self.currentRec=self.canvas().item_to_record[item]
    except KeyError:
      return
    self.drawCursor(item)
    
  def contentsMouseDoubleClickEvent(self, ev):
    self.setFocus()  
    try:
      items=self.canvas().collisions(ev.pos())
      self.setCursor(items[0])
      self.emit(PYSIGNAL("sigDoubleClickOn"), (self.currentItem, self.currentRec))
    except IndexError:
      pass
    
  def contentsDropEvent(self, ev):
    self.setFocus()
    try:
      items=self.canvas().collisions(ev.pos())
      self.setCursor(items[0])
      self.emit(PYSIGNAL("sigDropEventOn"), (self.currentItem, self.currentRec))
    except IndexError:
      pass
      
  def contentsMousePressEvent(self, ev):
    self.setFocus()
    try:
      items=self.canvas().collisions(ev.pos())
      self.setCursor(items[0])      
      self.emit(PYSIGNAL("sigMousePressedOn"), (self.currentItem, self.currentRec))
    except IndexError:
      pass
    
  def keyPressEvent(self, e):
    key=e.key()
    self.editor=None
    if key==Qt.Key_Up:
      self.scrollBy(0, 0 - self.canvas().lineSpacing)
    elif key==Qt.Key_Down:
      self.scrollBy(0, self.canvas().lineSpacing)
      
    elif key==Qt.Key_Left:
      self.scrollBy(-10, 0)
    elif key==Qt.Key_Right:
      self.scrollBy(10, 0)
      
    elif key==Qt.Key_Home:
      self.scrollBy(0 - self.canvas().width, 0)
    elif key==Qt.Key_End:
      self.scrollBy(self.canvas().width, 0)
    elif key==Qt.Key_PageUp:
      self.scrollBy(0, 0 - (self.height()/2))
    elif key==Qt.Key_PageDown:
      self.scrollBy(0, (self.height()/2))
      
    #elif key==Qt.Key_Enter or key==Qt.Key_Return:
    #  self.emit(PYSIGNAL("sigEnterPressed"), (self.currentItem, self.currentRec))
      
def main():
  qapp=QApplication(sys.argv)
  canvas=kuraIlCanvas()
  canvasView=kuraIlCanvasView(canvas)
  
  try:
    text=Config.app.getObject("lng_text", textnr=1)
  except dbRecordNotFoundException, errorMessage:
    print "Internal error, record not found:", errorMessage
    text=Config.app.createDefaultObject("lng_text")
    
  canvas.setText(text)
  canvas.resize(canvas.width + canvas.rightMargin, canvas.currentY)
  canvasView.show()
  
  qapp.connect(qapp, SIGNAL('lastWindowClosed()'), qapp, SLOT('quit()'))
  qapp.exec_loop()

if __name__=="__main__":
  sys.setappdefaultencoding("utf-8")
  if len(sys.argv)>1:
    if sys.argv[1]=='-p':
      import profile
      profile.run('main()')
  else:
    main()

__copyright__="""
/***************************************************************************
    copyright            : (C) 2000 by Boudewijn Rempt 
                           see copyright notice for license
    email                : boud@rempt.xs4all.nl
    Revision             : $Revision: 1.7 $
    Last edited          : $Date: 2001/01/31 20:04:36 $
    
    CVS Log:         
    $Log: kurailcanvasview.py,v $
    Revision 1.7  2001/01/31 20:04:36  boud
    Bugfixes.

    Revision 1.6  2001/01/30 20:04:42  boud
    Removed print statements.

    Revision 1.5  2001/01/24 19:18:47  boud
    Made more robust.

    Revision 1.4  2001/01/08 20:55:06  boud
    Cleanup for version 1.0

 ***************************************************************************/
"""
