from qt import *
from kuralib.config import Config
from resource import TRUE, FALSE
from dbobj.dbexceptions  import dbError

class kuraTextSelector(QListView):
  def __init__(self, searchRec, *args):
    apply(QListView.__init__,(self,) + args)
    self.setFont(Config.font)
    self.refresh(searchRec)
    self.connect(self, SIGNAL("returnPressed(QListViewItem *)")
                     , self.slotItemSelected)
    self.connect(self, SIGNAL("clicked(QListViewItem *)")
                     , self.slotItemSelected)
    self.connect(self, SIGNAL("doubleClicked(QListViewItem *)")
                     , self.slotItemSelected)
    

    self.clear()
    self.rows={}
    self.parents={}
      
    if Config.textSortCriterion=="language":
      self.setRootIsDecorated(TRUE)
      self.setShowSortIndicator(FALSE)
      self.setSorting(-1)
      self.setTreeStepSize(40)
      self.addColumn("Language")
      self.setColumnWidthMode(0, QListView.Maximum)
    elif Config.textSortCriterion=="project":
      self.setRootIsDecorated(TRUE)
      self.setShowSortIndicator(FALSE)
      self.setSorting(-1)
      self.setTreeStepSize(40)
      self.addColumn("Project")
      self.setColumnWidthMode(0, QListView.Maximum)
    elif Config.textSortCriterion=="user":
      self.setRootIsDecorated(TRUE)
      self.setShowSortIndicator(FALSE)
      self.setSorting(-1)
      self.setTreeStepSize(40)
      self.addColumn("User")
      self.setColumnWidthMode(0, QListView.Maximum)
    else: # filter
      self.setRootIsDecorated(FALSE)
      self.setShowSortIndicator(TRUE)
      self.setAllColumnsShowFocus(TRUE)
      self.addColumn("title")
      self.addColumn("language")
      self.addColumn("user")

    self.refresh(searchRec)

  def refresh(self, searchRec):
    self.setCursor(Qt.waitCursor)
    self.clear()
    self.rows={}
    self.parents={}
    if Config.textSortCriterion=="language":
      for language in Config.app.getObjects("lng_language"):
       parent=QListViewItem(self, language.getFieldValue("language"))
       self.parents[parent]=language
       for text in Config.app.getObjects("lng_text", languagenr=language.languagenr):
         item=QListViewItem(parent, text.getFieldValue("title"))
         self.rows[item]=text

    elif Config.textSortCriterion=="project":
      for project in Config.app.getObjects("lng_project"):
       parent=QListViewItem(self, project.getFieldValue("description"))
       self.parents[parent]=project
       for pjtx in Config.app.getObjects("lng_proj_text", projectnr=project.projectnr):
         text=Config.app.getObject("lng_text", textnr=pjtx.textnr)
         item=QListViewItem(parent, text.getFieldValue("title"))
         self.rows[item]=text
         
    elif Config.textSortCriterion=="user":
      for user in Config.app.getObjects("lng_user"):
       parent=QListViewItem(self, user.getFieldValue("name"))
       self.parents[parent]=user
       for text in Config.app.getObjects("lng_text", usernr=user.usernr):
         item=QListViewItem(parent, text.getFieldValue("title"))
         self.rows[item]=text
         
    else: # filter
      for text in Config.app.getObjects("lng_text", fields=searchRec.getFields()):
        item=QListViewItem(self, text.getFieldValue("title")
                               , text.getFieldValue("language")
                               , text.getFieldValue("user"))
        self.rows[item]=text

    self.setCursor(Qt.arrowCursor)
     
  def slotItemSelected(self, item):
    if item == None:
      return
    if self.rows.has_key(item):
      self.emit(PYSIGNAL("sigRecordSelected"), (self.rows[item], item))
         
  def slotAddItem(self, rec):
    if Config.textSortCriterion in ["language", "project"]:
      lvi=QListViewItem(self.currentItem().parent(), rec.getFieldValue("title"))
    elif Config.textSortCriterion == "user":
      for k, v in self.parents.items():
        if v.usernr==rec.usernr:
          lvi=QListViewItem(k, rec.getFieldValue("title"))
          break
    else:
      lvi=QListViewItem(self, rec.getFieldValue("title"), rec.getFieldValue("language"), rec.getFieldValue("user"))
    self.rows[lvi]=rec
    self.ensureItemVisible(lvi)

  def slotDeleteItem(self):
    if QMessageBox.warning(self
                  , "Kura"
                  , "Are you sure you want to irretrievably delete this text?"
                  , "Yes"
                  , "No"
                  ,QString()
                  , 1
                  , 1
                  )==0:
      rec = self.rows[self.currentItem()]
      try:
        rec.delete(TRUE)
        del self.rows[self.currentItem()]
        item=self.currentItem()
        parent=item.parent()
        if parent==None:
          parent=self
        parent.takeItem(item)
      except dbError, dberr:
        QMessageBox.information(self, "Kura Error while deleting", dberr.errorMessage)

      self.emit(PYSIGNAL("sigItemDeleted"),())      

  def slotNewItem(self):

    if Config.textSortCriterion in ["language", "project", "user"]:
      if self.currentItem() in self.parents.keys():
        parent=self.parents[self.currentItem()]
      else:
        parent=self.parents[self.currentItem().parent()]

    if Config.textSortCriterion == "language":
      rec=Config.app.createDefaultObject("lng_text", languagenr=parent.languagenr)
    elif Config.textSortCriterion == "project":
      rec=Config.app.createDefaultObject("lng_text", projectnr=parent.projectnr)
    else:
      rec=Config.app.createDefaultObject("lng_text")

    self.emit(PYSIGNAL("sigCreateNewItem"),(rec,))  
    

  def slotUpdateItem(self, rec, lvi):
    if self.rows.has_key(lvi):
      self.rows[lvi]=rec
      if Config.textSortCriterion in ["language", "project", "user"]:
        lvi.setText(0, rec.title)
      else:
        lvi.setText(0, rec.getFieldValue("title"))
        lvi.setText(1, rec.getFieldValue("language"))
        lvi.setText(2, rec.getFieldValue("user"))
  
  def keyPressEvent(self, e):
    if e.key()==Qt.Key_Enter or e.key()==Qt.Key_Return:
      self.slotItemSelected(self.currentItem())
    elif e.key()==Qt.Key_F2:
      if Config.textSortCriterion=="filter":
        self.emit(PYSIGNAL("sigFindRecord"),())
    elif e.key()==Qt.Key_Delete:
      self.slotDeleteItem()
    elif e.key()==Qt.Key_Insert:
      self.slotNewItem()
    else:
      QListView.keyPressEvent(self, e)

  def currentRecord(self):
    if self.rows.has_key(self.currentItem()):
      return (self.rows[self.currentItem()], self.currentItem())
    elif self.parents.has_key(self.currentItem()):
       if self.currentItem().childCount() > 0:
         return (self.rows[self.currentItem().firstChild()], self.currentItem())
      

__copyright__="""
/***************************************************************************
    copyright            : (C) 2000 by Boudewijn Rempt 
                           see copyright notice for license
    email                : boud@rempt.xs4all.nl
    Revision             : $Revision: 1.7 $
    Last edited          : $Date: 2001/01/30 20:04:42 $
    
    CVS Log:         
    $Log: kuratextselector.py,v $
    Revision 1.7  2001/01/30 20:04:42  boud
    Removed print statements.

    Revision 1.6  2001/01/15 20:21:09  boud
    Added import/export filters, bugfixes.

    Revision 1.5  2001/01/08 20:55:06  boud
    Cleanup for version 1.0

 ***************************************************************************/
"""
