import sys, string, types
from qt import *
from kuralib.config import Config

TRUE=1
FALSE=0

class InterlinearWordSet:

  def __init__(self):
    self.wordset={}
    self.index=[]

  def __len__(self):
    return len(self.index)

  def append(self, recType, rec):
    if self.wordset.has_key(recType)==FALSE:
      self.wordset[recType]=[]
      self.index.append(recType)
    
    if type(rec) == types.ListType:
      self.wordset[recType]=self.wordset[recType] + rec
    else:
      self.wordset[recType].append(rec)
    
class InterlinearLineSet:

  def __init__(self):
    self.lineset=[]
    self.depth=0
    self.word=InterlinearWordSet()
    self.wordset=InterlinearWordSet()
    
  def __len__(self):
    return len(self.lineset)

  def getTextLines(self):
    lines={}
    index=[]
    linelength=0
    for word in self.lineset:
      for linetype in word.index:
        #
        # Create a line for this linetype if it isn't there
        # already
        #
        if lines.has_key(linetype) == FALSE:
          lines[linetype]=""
          index.append(linetype)
        #
        # Join the individual components 
        # FIXME: get delimiters from database
        #
        if linetype[:3]=="tag":
          parts=[]
          for part in word.wordset[linetype]:
            if part is None:
              parts.append("#")
            else:
              desc=part.getDescription(TRUE)
              if desc==None:
                desc="#"
              parts.append(desc)
          item=string.join(parts, u".")
        else:
          parts=[]
          for part in word.wordset[linetype]:
            parts.append(part.getFieldValueAsString(linetype.split("-")[1]))
          item=string.join(parts, u".")
          
        # append item to the right line
        lines[linetype]=lines[linetype] + " " + item

        # check length of the line
        if len(lines[linetype]) > linelength: 
          linelength=len(lines[linetype])
         
      # left-justify all lines
      for k, v in lines.items():
        lines[k]=v.ljust(linelength)
    return index, lines

  def addLineItem(self, recType, rec):
    self.wordset.append(recType, rec)
    
  def addWordBreak(self):
    self.lineset.append(self.wordset)
    if self.depth < len(self.wordset):
      self.depth=len(self.wordset)
    self.wordset=InterlinearWordSet()
    
class KuraDOM(QObject):
  """
    Create a DOM consisting of regular dbObj objects
    representing a complete text document, or, a list
    of documents.
    
    Additionally, the tags belonging to texts, streams
    and elements are indexed using a dictionary on the
    tag.tag field.
    
    Creating the dom is a matter of parsing a text in
    some form or reading it from the database, and calling
    the appropriate functions. See kuradbreader.py for an
    example.
    
    The DOM can be read using two functions: walkTree,
    which emits PYSIGNALS for every element and traverses
    the DOM in tree order, and walkText, which emits a
    PYSIGNAL for every line and walks the DOM in the
    order defined in the configurarion.
    
  """
  def __init__(self, *args): 
    apply(QObject.__init__,(self,)+args)
    self.root=[]
    self.currentText=None
    self.currentStream=None
    self.currentElement=None
  
  def _addDict(self, dict, key, item):
    if dict.has_key(key):
      dict[key].append(item)
    else:
      dict[key]=[item]
      
  def addText(self, fields):
    text=Config.app.createObject("lng_text", fields=fields)
    text.dictTags={}
    self.root.append(text)
    self.currentText=text
    return text
    
  def addStream(self, fields):
    stream=Config.app.createObject("lng_stream", fields=fields)
    stream.dictTags={}
    self.currentText.streams.append(stream)
    self.currentStream=stream
    return stream
    
  def addElement(self, fields, parentElement=None):
    element=Config.app.createObject("lng_element", fields=fields)
    element.dictTags={}
    if parentElement==None:
      self.currentStream.elements.append(element)
    else:
      parentElement.elements.append(element)
    self.currentElement=element
    return element

  def addTextTag(self, fields):
    tag=Config.app.createObject("lng_text_tag", fields)
    self.currentText.tags.append(tag)
    self._addDict(self.currentText.dictTags, tag.tag, tag)
    return tag
  
  def addStreamTag(self, fields):
    tag=Config.app.createObject("lng_stream_tag", fields)
    self.currentStream.tags.append(tag)
    self._addDict(self.currentStream.dictTags, tag.tag, tag)
    return tag
      
  def addElementTag(self, fields):
    tag=Config.app.createObject("lng_element_tag", fields)
    self.currentElement.tags.append(tag)
    self._addDict(self.currentElement.dictTags, tag.tag, tag)    
    return tag
  
  def __walkElement(self, element, f=None):
    if f: f(element)
    self.emit(PYSIGNAL("sigElementStarted"), (element,))
    for tag in element.tags:
      if f:f(tag)
      self.emit(PYSIGNAL("sigElementTag"), (tag,))
    for subelement in element.elements:
      self.__walkElement(subelement)
    self.emit(PYSIGNAL("sigElementEnded"), (element,))
    
  def walkTree(self, f=None):
    """Walk through the Kura DOM, emitting a signal 
       every time an object is started or completed.
       
       Note 1: elements can be nested
       
       Note 2: tags do not emit an end signal since
               they cannot be nested.
    """
    for text in self.root:
      if f: f(text)
      self.emit(PYSIGNAL("sigTextStarted"), (text,))
      for stream in text.streams:
        if f:f(stream)
        self.emit(PYSIGNAL("sigStreamStarted"), (stream,))
        for tag in stream.tags:
          if f: f(tag)
          self.emit(PYSIGNAL("sigStreamTag"), (tag,))
        for element in stream.elements:
          self.__walkElement(element, f)
        self.emit(PYSIGNAL("sigStreamEnded"), (stream,))            
      self.emit(PYSIGNAL("sigTextEnded"), (text,))
      

  def _walkElementSet(self, element, ilLineSet, depth):
    for elementDef in Config.InterLinearElementPresentation.split():
      base, field=elementDef.split(".")
      if base=="element":
        ilLineSet.addLineItem("element" + "-" + field + "-" + str(depth), element)
      elif base=="element_tag":
        ilLineSet.addLineItem("tag" + "-" + field + "-" + str(depth), element.dictTags.get(field, None))
      elif base=="element_element":
        for subelement in element.elements:
          self._walkElementSet(subelement, ilLineSet, depth+1)

  def _walkStream(self, text):
    for stream in text.streams:
      ilLineSet=InterlinearLineSet()
      for streamDef in Config.InterlinearStreamPresentation.split():
        base, field=streamDef.split(".")
        if base=="stream":
          self.emit(PYSIGNAL("sigStreamLine"), (field, stream))
        elif base=="stream_tag":
          self.emit(PYSIGNAL("sigStreamTag"), (field, stream.dictTags.get(field,[])))
        elif base=="element":
          for element in stream.elements:
            self._walkElementSet(element, ilLineSet, 0)
            ilLineSet.addWordBreak()
          self.emit(PYSIGNAL("sigLineSet"), (ilLineSet,))
        
  def walkText(self):
    """Walk through the text giving it line by line
       according to the definition given in the 
       configuration file .kurarc.
       
       Note: perhaps this definitions should be stored
       elsewhere, for instance with the project.
       
       The data the othder signals emit consist of two 
       elements: the fieldname as defined in the configuration
       and the whole object.
       
       Note 3: this mechanism _must_ become more intelligent. See
       separate note in kura/notes.
       
    """
    for text in self.root:
      for textDef in Config.InterLinearTextPresentation.split():
        base, field=textDef.split(".")
        if base=="text":
          self.emit(PYSIGNAL("sigTextLine"), (field, text))
        elif base=="text_tag":
          self.emit(PYSIGNAL("sigTextTag"), (field, text.dictTags.get(field, [])))
        elif base=="stream":
          self._walkStream(text)
