import sys, string
from qt import *
from kuradom import KuraDOM
from kuralib.config import Config
from kuradom import KuraDOM
from kuradbreader import KuraDBReader



def nvl(item):
  if item==None:
    return "#"
  else:
    return item

class KuraTagWriter(QObject):
  """
  Writes a tagged interlinear text to standard output, similar
  to the the way Shoebox saves its texts. Note that this is 
  not a complete export of all data pertaining to a text - you
  cannot read it in again, unless you redefine the presention
  template. For an example, see kuratagexport.py
  """
  
  def __init__(self, dom, *args):
    apply(QObject.__init__,(self,)+args)

    self.dom=dom

    self.elementDepth=[]
    self.currentTextnr=None
    self.currentStreamnr=None
    self.currentElementnr=None
    
    self.connect(self.dom, PYSIGNAL("sigTextLine"), self.textLine)
    self.connect(self.dom, PYSIGNAL("sigStreamLine"), self.streamLine)
    self.connect(self.dom, PYSIGNAL("sigLineSet"), self.complexLine)
    self.connect(self.dom, PYSIGNAL("sigTextTag"), self.simpleTag)
    self.connect(self.dom, PYSIGNAL("sigStreamTag"), self.simpleTag)

    self.tagDefinitions={}
    self.elementTypeCodes={}
    
    self.styles={}
    for style in Config.app.getObjects("lng_stylecode"):
      self.styles[style.stylecode]=style
    self.defaultStyle=Config.app.createDefaultObject("lng_stylecode")

  def _cache(self, cache, key, tableName, **args):
    if cache.has_key(key):
      return cache[key]
    else:
      rec=Config.app.getObject(tableName, fields=args)
      cache[key]=rec
      return rec

  def _getTagStyle(self, tagRecord):
    if tagRecord==None:
      print "Empty tagRecord"
      return self.defaultStyle
    else:
      tagDefinition=self._cache( self.tagDefinitions
                               , tagRecord.tag
                               , "lng_tag"
                               , tag=tagRecord.tag)
      style=self.styles.get( tagDefinition.stylecode
                           , self.defaultStyle)
      return style

  def _getElementStyle(self, elementRecord):
    elementTypeCode=self._cache(self.elementTypeCodes
                               , element.elementtypecode
                               , "lng_elementtypecode"
                               , elementtypecode=element.elementtypecode)
    style=self.styles.get( elementTypeCode.stylecode
                         , self.defaultStyle)
    return style

  def textLine(self, field, record):
    marker="\\text." + field
    print marker.ljust(self.marginwidth), record.getFieldValue(field)
    
  def streamLine(self, field, record):
    marker="\\stream." + field
    print marker.ljust(self.marginwidth), record.getFieldValue(field)
    print

  def simpleTag(self, field, recs):
    for record in recs:
      style=self._getTagStyle(record)
      marker="\\"+field
      print marker.ljust(self.marginwidth), record.getDescription(style.showifnull)
      print

  def complexLine(self, lineset):
    index, lines=lineset.getTextLines()
    for key in index:
      marker="\\" + string.join(string.split(key,"-")[1:],".")
      print marker.ljust(self.marginwidth), lines[key][1:]
    print
      
  def start(self, mw, out=sys.stdout):
    sys.stdout=out
    self.marginwidth=mw
    print "\\kura v1.0 Interlinear Text"
    print
    self.dom.walkText()
        
def main(args):
  dbr=KuraDBReader()
  for arg in args:
    dbr.start(arg)
  tagsaver=KuraTagWriter(dbr.getDom())
  tagsaver.start()
  
if __name__=="__main__":
  main(sys.argv[1:])
