FALSE=0
TRUE=1

import time
import os
import os.path
import string
import urllib
from kuradocbuilder import KuraDocBuilder

class KuraDocument:
 
  def __init__(self, app, args, wfile):
    self.app=app
    self.kuradocbuilder=KuraDocBuilder(self.app)
    self.vars={}
    self.xml=open(os.path.join(os.environ["KURASERVERDIR"],"templates/tpl_default.xml"),"r").read()
    self.wfile=wfile
    command=""
    for k, v in args.items():
      command=command + k + '="' + v + '" '
    self.vars['command']=command
    self.vars['table']=args['table']
    self.vars['key']=command
    self.vars['date']=time.asctime(time.localtime(time.time()))
    self.vars['affiliation_url']="http://www.valdyas.org/linguistics/index.html"
   
  def getList(self):
    self.vars['command']='<kura_list %(command)s></kura_list>' % self.vars
    return self.kuradocbuilder.document(self.xml % self.vars, self.wfile )

  def getRecord(self):
    self.vars['command']='<kura_record %(command)s></kura_record>' % self.vars
    return self.kuradocbuilder.document(self.xml % self.vars, self.wfile )

  def getContents(self):
    """
      return a table of contents. Special argument: indexfield=fieldname

      e.g.: KURA?command=contents?table=lng_lex?languagenr=6?indexfield=form
    """
    self.vars['command']='<kura_contents %(command)s></kura_contents>' % self.vars
    return self.kuradocbuilder.document(self.xml % self.vars, self.wfile )
    
class KuraController:

  def __init__(self, app):
    self.app = app
    
  def __parse__(self, cmdString):
    """
      Split a Kura command into its component parts,
      delimited by a question mark:
      
      /KURA?table=lng_lex?command=list?languagenr=1
       
    """
    name_value_pairs = string.split(urllib.unquote_plus(cmdString), '?')
    dict = {}
    try:
      for name_value in name_value_pairs:
        nv = string.split(name_value, '=')
        if len(nv) != 2:
          raise ValueError, "bad field: %s" % `name_value`
        name = nv[0]
        value = nv[1]
        if dict.has_key (name):
            dict[name].append(value)
        else:
            dict[name] = value # was: [value]
      return dict
    except:
      raise ValueError,  "Fatal error with command: " + cmdString

  def execute(self, cmdString, wfile):
    paramDict=self.__parse__(cmdString)

    if paramDict.has_key('command'):
      command=paramDict['command']
      del paramDict['command']
      doc=KuraDocument(self.app, paramDict, wfile)
      if   command=='list':
        doc.getList()
      elif command=='record':
        doc.getRecord()
      elif command=='contents':
        doc.getContents()
      else:
        raise SyntaxError, "Fatal error with command: " + command + "Parameters" + str(paramDict)
    else:
      raise SyntaxError, "No command given"

__copyright__="""
/***************************************************************************
    copyright            : (C) 2000 by Boudewijn Rempt 
                           see copyright notice for license
    email                : boud@rempt.xs4all.nl
    Revision             : $Revision: 1.2 $
    Last edited          : $Date: 2001/01/08 20:55:07 $
    
    CVS Log:         
    $Log: kuracontroller.py,v $
    Revision 1.2  2001/01/08 20:55:07  boud
    Cleanup for version 1.0

 ***************************************************************************/
"""
