#!/usr/bin/env python


TRUE=1
FALSE=0


class KuraHTMLWriter:
  """
   Generic class to write the results of a selection out in html,
   either in single record or in table mode.
   
   The 'out' parameter is a the write function of a file(-like) object:
   i.e.: out=open("myfile","w").write
   or    out=sys.stdout.write

   Notes: I'd still like to decouple this a bit more: i.e., the tbl
   parameter brings a reference to the entire repository with it...
   
  """
  def startRow(self, out):
    out('<tr>\n')

  def endRow(self, out):
    out('</tr>\n')

  def addCol(self, out, contents):
     out('<td>%s</td>\n' % str(contents))

  def presentField(self, fielddef, value):
    if fielddef.url==TRUE:
      return '<a href="%s">%s</a>' % (value, value)
    else:
      return value

  def masterLink(self, fields, value, relationDef):
    """
      This will generate links that tie the whole database together.
      relationDef.rtable is the related table, the master.
      relationDef.descriptors.local is the fieldname of the lookup
      field as selected present in the row.fields dictionary.
    """
    if value==None or fields[relationDef.descriptors.local]==None or value==0:
      return( "&lt;None&gt;")
    else:
      return(u'<a href="KURA?command=record?table=%s?%s=%s">%s</a>' %
           ( relationDef.rtable
           , str(relationDef.keys.foreign)
           , str(value)
           , str(fields[relationDef.descriptors.local])
           )
         )
     
  def recordHTML(self, out, keys={}, includeChildTables=FALSE):
    """
      Generic fallback method.
      
      Generates a chunk of html presenting the results of a query
      in record form, with links to all child tables.

      I'd like to make this more generic, but even a Tudor chimney winds
      down to pot somewhere - and at the end, there's always something
      that's specific.
      
    """
    out(u"<h1>%s</h1>" % self.table)
    tpl=u"<tr><td>%s</td><td>%s</td></tr>\n"
    tableDef=self.app.tables[self.table] # shortcut to table definition
    queryRec=self.recObj(self.app, table=self.table, fields=keys) # query template
    self.select(queryRec) # select the desired rows
    
    # the records
    for row in self.rows:
      pkeys={} # for included child tables
      cstr=u""  # for links to child tables
      out("<table>")
      #
      # Show the fields
      #
      for field, fieldDef in tableDef.orderedFieldList():
        if fieldDef.dialog==TRUE:
          if fieldDef.owner==TRUE and fieldDef.relation==None:
            out(tpl % ( fieldDef.label, self.presentField(fieldDef, row.getFieldValue(field))))
            
          elif fieldDef.relation <> None:
            # Link to the master of foreign key
            # show the descriptor field, i.e. the corresponding not owner field
            if row.getFieldValue(field)<>None:
              print "Relation", row.getFieldValue(self.app.relations[fieldDef.relation].descriptors.local)
              out(tpl % (fieldDef.label, u'<a href="KURA?command=record?table=%s?%s=%s">%s</a>' % ( 
                                                  self.app.relations[fieldDef.relation].rtable
                                                , self.app.relations[fieldDef.relation].keys.foreign
                                                , row.getFieldValue(field)
                                                , row.getFieldValue(self.app.relations[fieldDef.relation].descriptors.local)
                                                )
                                         )
                        )
              
        if fieldDef.pk==TRUE:
          pkeys[field]=row.getFieldValue(field)
          cstr=u"%s?%s=%s" % (cstr, field, row.getFieldValue(field))
      out(r"</table>" + "\n")
      #
      # Process the child tables
      #
      out("<ul>")
      for childtable in tableDef.childtables.keys():
        if row.hasChildren(childtable):
          if includeChildTables:
            self.app.createTableObject(childtable).listHTML(out, pkeys)
          else:
            out(u'<li><a href="KURA?command=list?table=%s%s">%s</a></li>\n' % (childtable, cstr, childtable))
      out("</ul>")

  def contentsHTML(self, out, indexfield, keys={}):
    tableDef=self.app.tables[self.table]
    out(u"<h1>%s</h1>" % self.table)    
    out(u"<h1>Table of Contents of %s</h1>\n<ul> "% self.table)
    keylist=""
    for k,v in keys.items():
      keylist = keylist + "?%s=%s" % (k, v)
      
    for key in "abcdefghijklmnopqrstuvwxyz":
      s=u'<li><a href="/KURA?command=list?table=%s?%s=%s' % (self.table, indexfield, key)
      s=s + u'%'
      s=s + u'%s"><strong>%s</strong></a></li>\n' %(keylist, key)
      out(s)
      
    out("</ul>")
    
  def listHTML(self, out, keys={}):
    """
      Generic fallback method.

      Presents a HTML table containing the records that are selected
      by keys{}. Offers links to all master records and a single record
      view of each record from the table. 

      Comparable to the gui client listview: see kuraform.py.
      
    """
    out(u"<h1>%s</h1>" % self.app.getLabel(self.table))
    queryRec=self.recObj(self.app, table=self.table, fields=keys)
    self.select(queryRec)
    # first col is for record gif
    out("\n<table border=1>\n<tr><td></td>")
    tableDef=self.app.tables[self.table]

    # create table header: every field that's included in the list
    # comes into the table, just like the gui

    for field, fieldDef in tableDef.fieldList:
      if fieldDef.inList==TRUE:
        self.addCol(out, field or fieldDef.label)
    self.endRow(out)
    
    # Then add the rows.
    for row in self.rows:
      self.startRow(out)
      self.addCol(out, u'<a href="KURA?command=record?table=%s?%s=%s"><img src="graphics/record.png"></a>'
                       % ( self.table, tableDef.primarykey, row.getFields()[tableDef.primarykey])
                 )
      for field, fieldDef in tableDef.fieldList:
        # only fields that should appear in the list and 
        # that are not lookup fields. 
        if fieldDef.inList==TRUE:
          if fieldDef.owner==TRUE:
            self.addCol(out, self.presentField(fieldDef, row.getFields()[field]))
        elif fieldDef.relation<>None:
          # Link to the master of foreign key
          # show the descriptor field, i.e. the corresponding not owner field
          out("<td>")
          fields=row.getFields()
          out(self.masterLink(fields, fields[field], self.app.relations[fieldDef.relation]))
          out("</td>")
          
      self.endRow(out)
    out('</table>')

def installWriter(base):
  base.__bases__=base.__bases__ + (KuraHTMLWriter,)
__copyright__="""
/***************************************************************************
    copyright            : (C) 2000 by Boudewijn Rempt 
                           see copyright notice for license
    email                : boud@rempt.xs4all.nl
    Revision             : $Revision: 1.3 $
    Last edited          : $Date: 2001/01/08 20:55:07 $
    
    CVS Log:         
    $Log: kurahtmlwriter.py,v $
    Revision 1.3  2001/01/08 20:55:07  boud
    Cleanup for version 1.0

 ***************************************************************************/
"""
